@@ -1,8 +1,10 @@
 
 
 #include "WINGsP.h"
+#include "wconfig.h"
 
 #include <X11/Xutil.h>
+#include <X11/Xatom.h>
 #include <X11/keysym.h>
 #include <X11/cursorfont.h>
 
@@ -410,7 +412,7 @@ loadPixmaps(WMScreen *scr)
     if (!image)
 	image = RLoadImage(scr->rcontext, X_WINGS_IMAGES_FILE, 0);
     if (!image) {
-	wwarning("WINGs: could not load widget images file: %s", 
+	wwarning(_("WINGs: could not load widget images file: %s"), 
 		 RMessageForError(RErrorCode));
 	return False;
     }
@@ -583,7 +585,7 @@ WMCreateScreenWithRContext(Display *display, int screen, RContext *context)
 	    "WM_STATE"
     };
     Atom atoms[sizeof(atomNames)/sizeof(char*)];
-    int i = 0;
+    int i;
 
     if (!initialized) {
 
@@ -616,6 +618,45 @@ WMCreateScreenWithRContext(Display *display, int screen, RContext *context)
 
     scrPtr->fontCache = WMCreateHashTable(WMStringPointerHashCallbacks);
 
+    /* Create missing CUT_BUFFERs */
+    {
+        Atom *rootWinProps;
+        int exists[8] = {0, 0, 0, 0, 0, 0, 0, 0};
+        int count;
+
+        rootWinProps = XListProperties(display, scrPtr->rootWin, &count);
+        for (i=0; i<count; i++) {
+            switch(rootWinProps[i]) {
+            case XA_CUT_BUFFER0:
+                exists[0] = 1; break;
+            case XA_CUT_BUFFER1:
+                exists[1] = 1; break;
+            case XA_CUT_BUFFER2:
+                exists[2] = 1; break;
+            case XA_CUT_BUFFER3:
+                exists[3] = 1; break;
+            case XA_CUT_BUFFER4:
+                exists[4] = 1; break;
+            case XA_CUT_BUFFER5:
+                exists[5] = 1; break;
+            case XA_CUT_BUFFER6:
+                exists[6] = 1; break;
+            case XA_CUT_BUFFER7:
+                exists[7] = 1; break;
+            default:
+                break;
+            }
+        }
+        if (rootWinProps) {
+            XFree(rootWinProps);
+        }
+        for (i=0; i<8; i++) {
+            if (!exists[i]) {
+                XStoreBuffer(display, "", 0, i);
+            }
+        }
+    }
+
     scrPtr->ignoredModifierMask = 0;
     {
 	int i;
@@ -713,8 +754,8 @@ WMCreateScreenWithRContext(Display *display, int screen, RContext *context)
 	scrPtr->boldFont = scrPtr->normalFont;
 
     if (!scrPtr->normalFont) {
-	wwarning("could not load any fonts. Make sure your font installation"
-		 "and locale settings are correct.");
+	wwarning(_("could not load any fonts. Make sure your font installation"
+		 "and locale settings are correct."));
 
 	return NULL;
     }
@@ -816,11 +857,8 @@ WMCreateScreenWithRContext(Display *display, int screen, RContext *context)
     XInternAtoms(display, atomNames, sizeof(atomNames)/sizeof(char*), False,
 		 atoms);
 #else
-    {
-	int i;
-	for (i = 0; i < sizeof(atomNames)/sizeof(char*); i++) {
-	    atoms[i] = XInternAtom(display, atomNames[i], False);
-	}
+    for (i = 0; i < sizeof(atomNames)/sizeof(char*); i++) {
+        atoms[i] = XInternAtom(display, atomNames[i], False);
     }
 #endif
 
@@ -852,15 +890,14 @@ WMCreateScreenWithRContext(Display *display, int screen, RContext *context)
     scrPtr->wmIconDragOffsetAtom = atoms[i++];
 
     scrPtr->wmStateAtom = atoms[i++];
-	
-    scrPtr->rootView = W_CreateRootView(scrPtr);
 
+    scrPtr->rootView = W_CreateRootView(scrPtr);
 
     scrPtr->balloon = W_CreateBalloon(scrPtr);
 
 
     W_InitApplication(scrPtr);
-    
+
     return scrPtr;
 }
 
