@@ -151,13 +151,16 @@ typedef enum {
 #define WDIS_CENTER	1	       /* center of screen */
 #define WDIS_TOPLEFT	2	       /* top left corner of screen */
 #define WDIS_FRAME_CENTER 3	       /* center of the frame */
-
+#define WDIS_NONE       4
 
 /* keyboard input focus mode */
 #define WKF_CLICK	0
-#define WKF_POINTER	1
 #define WKF_SLOPPY	2
 
+/* colormap change mode */
+#define WCM_CLICK	0
+#define WCM_POINTER	1
+
 /* window placement mode */
 #define WPM_MANUAL	0
 #define WPM_CASCADE	1
