@@ -47,6 +47,7 @@
 #include "appmenu.h"
 #include "winspector.h"
 #include "workspace.h"
+#include "wsound.h"
 
 #ifdef GNOME_STUFF
 # include "gnome.h"
@@ -55,9 +56,6 @@
 # include "kwm.h"
 #endif
 
-#ifdef WSOUND
-#include "wsound.h"
-#endif
 
 
 /****** Global Variables ******/
@@ -187,7 +185,7 @@ wSetFocusTo(WScreen *scr, WWindow  *wwin)
 
     if (wwin->flags.mapped && !WFLAGP(wwin, no_focusable)) {
 	/* install colormap if colormap mode is lock mode */
-	if (wPreferences.colormap_mode==WKF_CLICK)
+	if (wPreferences.colormap_mode==WCM_CLICK)
 	    wColormapInstallForWindow(scr, wwin);
 
 	/* set input focus */
@@ -272,9 +270,7 @@ wShadeWindow(WWindow  *wwin)
 
     XLowerWindow(dpy, wwin->client_win);    
 
-#ifdef WSOUND
     wSoundPlay(WSOUND_SHADE);
-#endif
 
 #ifdef ANIMATIONS
     if (!wwin->screen_ptr->flags.startup && !wwin->flags.skip_next_animation
@@ -359,9 +355,7 @@ wUnshadeWindow(WWindow  *wwin)
     wwin->flags.mapped = 1;
     XMapWindow(dpy, wwin->client_win);
 
-#ifdef WSOUND
     wSoundPlay(WSOUND_UNSHADE);
-#endif
 
 #ifdef ANIMATIONS
     if (!wPreferences.no_animations && !wwin->flags.skip_next_animation) {
@@ -504,8 +498,14 @@ wMaximizeWindow(WWindow *wwin, int directions)
     }
 
     wWindowConstrainSize(wwin, &new_width, &new_height);
+    
+    wWindowCropSize(wwin, usableArea.x2-usableArea.x1, 
+		    usableArea.y2-usableArea.y1,
+		    &new_width, &new_height);    
+    
     wWindowConfigure(wwin, new_x, new_y, new_width, new_height);
 
+    
 #ifdef GNOME_STUFF
     wGNOMEUpdateClientStateHint(wwin, False);
 #endif
@@ -514,9 +514,7 @@ wMaximizeWindow(WWindow *wwin, int directions)
     wKWMSendEventMessage(wwin, WKWMChangedClient);
 #endif
 
-#ifdef WSOUND
     wSoundPlay(WSOUND_MAXIMIZE);
-#endif
 }
 
 
@@ -548,9 +546,7 @@ wUnmaximizeWindow(WWindow *wwin)
     wKWMSendEventMessage(wwin, WKWMChangedClient);
 #endif
 
-#ifdef WSOUND
     wSoundPlay(WSOUND_UNMAXIMIZE);
-#endif
 }
 
 #ifdef ANIMATIONS
@@ -969,9 +965,7 @@ wIconifyWindow(WWindow *wwin)
     unmapTransientsFor(wwin);
 
     if (present) {
-#ifdef WSOUND
 	wSoundPlay(WSOUND_ICONIFY);
-#endif
 
 	XUngrabPointer(dpy, CurrentTime);
 	wWindowUnmap(wwin);
@@ -1123,9 +1117,7 @@ wDeiconifyWindow(WWindow  *wwin)
 	XUnmapWindow(dpy, wwin->icon->core->window);
     }
 
-#ifdef WSOUND
     wSoundPlay(WSOUND_DEICONIFY);
-#endif
 
     /* if the window is in another workspace, do it silently */
 #ifdef ANIMATIONS
@@ -1241,9 +1233,7 @@ hideWindow(WIcon *icon, int icon_x, int icon_y, WWindow *wwin, int animate)
 
     wClientSetState(wwin, IconicState, icon->icon_win);
     flushExpose();
-#ifdef WSOUND
     wSoundPlay(WSOUND_HIDE);
-#endif
 #ifdef ANIMATIONS
     if (!wwin->screen_ptr->flags.startup && !wPreferences.no_animations &&
 	!wwin->flags.skip_next_animation && animate) {
@@ -1390,9 +1380,7 @@ unhideWindow(WIcon *icon, int icon_x, int icon_y, WWindow *wwin, int animate,
     wwin->flags.hidden=0;
     wwin->flags.mapped=1;
     
-#ifdef WSOUND
     wSoundPlay(WSOUND_UNHIDE);
-#endif
 #ifdef ANIMATIONS
     if (!wwin->screen_ptr->flags.startup && !wPreferences.no_animations 
 	&& animate) {
