@@ -319,8 +319,8 @@ updateDockNumbers(WScreen *scr)
     numbers_gc = XCreateGC(dpy, dicon->icon->core->window,
 			   my_v_mask, &my_gc_values);
 
-    ws_numbers = malloc(20);
-    sprintf(ws_numbers, "%i [ %i ]", scr->current_workspace+1,
+    ws_numbers = wmalloc(20);
+    snprintf(ws_numbers, 20, "%i [ %i ]", scr->current_workspace+1,
 	    ((scr->current_workspace/10)+1));
     length = strlen(ws_numbers);
     
@@ -457,14 +457,14 @@ wAppIconPaint(WAppIcon *aicon)
     if (index > 0) {
 	char buf[16];
 	
-	sprintf(buf, "%i", index);
+	snprintf(buf, sizeof(buf), "%i", index);
 	
 	WMDrawString(scr->wmscreen, aicon->icon->core->window, 
 		     scr->clip_title_gc, scr->title_font,
-		     1, 1, buf, strlen(buf));
+		     3, 3, buf, strlen(buf));
     }
-    
-    
+
+
     if (aicon->omnipresent)
         drawCorner(aicon->icon);
 
@@ -912,9 +912,7 @@ appIconMouseDown(WObjDescriptor *desc, XEvent *event)
 		    }
 		}
 
-#ifdef WSOUND
 		wSoundPlay(WSOUND_DOCK);
-#endif
             } else {
 		if (movingSingle) {
 		    /* move back to its place */
