@@ -47,12 +47,8 @@
 #include "actions.h"
 #include "defaults.h"
 #include "workspace.h"
-
 #include "dock.h"
-
-#ifdef WSOUND
 #include "wsound.h"
-#endif
 
 
 /******** Global variables ********/
@@ -305,25 +301,6 @@ wApplicationCreate(WScreen *scr, Window main_window)
 #endif /* USER_MENU */
 
 
-    {
-	WApplication *tmp = scr->wapp_list;
-	
-	wapp->next = NULL;
-	wapp->prev = NULL;
-
-	/* append to app list */
-	if (!tmp) {
-	    scr->wapp_list = wapp;
-	} else {
-	    while (tmp->next) {
-		tmp = tmp->next;
-	    }
-	    tmp->next = wapp;
-	    wapp->prev = tmp;
-	}
-    }
-    
-    
     /*
      * Set application wide attributes from the leader.
      */
@@ -436,11 +413,56 @@ wApplicationCreate(WScreen *scr, Window main_window)
         if (!tmp)
 	    extractClientIcon(wapp->app_icon);
     }
+
+    /* set the application instance index */
+    {
+        WApplication *list = scr->wapp_list;
+        WApplication *prev = NULL;
+	int index = 0;
+	WWindow *wwin = wapp->main_window_desc;
+/*
+    if (!WFLAGP(wwin, collapse_appicons))
+	return 0;
+ */
+
+	/* look for a free index # */
+	while (list) {
+	    if (strcmp(wwin->wm_instance,
+		       list->main_window_desc->wm_instance) == 0
+		&&
+		strcmp(wwin->wm_class,
+		       list->main_window_desc->wm_class) == 0) {
+		
+		if (list->index == index) {
+		    index++;
+		    
+		    /* restart list traversal */
+                    list = scr->wapp_list;
+                    prev = NULL;
+		    continue;
+		}
+	    }
+
+            prev = list;
+	    list = list->next;
+	}
+	
+        wapp->index = index;
+
+	wapp->next = NULL;
+	wapp->prev = NULL;
+
+	/* append to app list */
+	if (!prev) {
+	    scr->wapp_list = wapp;
+	} else {
+	    prev->next = wapp;
+	    wapp->prev = prev;
+	}
+    }
     
     
-#ifdef WSOUND
     wSoundPlay(WSOUND_APPSTART);
-#endif
 
 #ifdef DEBUG
     printf("Created application for %x\n", (unsigned)main_window);
@@ -517,9 +539,7 @@ wApplicationDestroy(WApplication *wapp)
         wArrangeIcons(scr, True);
     }
 
-#ifdef WSOUND
     wSoundPlay(WSOUND_APPEXIT);
-#endif
 }
 
 
@@ -560,30 +580,6 @@ wApplicationSetCollapse(WApplication *app, Bool flag)
 int
 wApplicationIndexOfGroup(WApplication *app)
 {
-    WApplication *list = app->main_window_desc->screen_ptr->wapp_list;
-    int index = 0;
-    WWindow *wwin = app->main_window_desc;
-/*
-    if (!WFLAGP(wwin, collapse_appicons))
-	return 0;
- */
-    
-    while (list) {
-	if (app == list)
-	    return index;
-
-	if (strcmp(wwin->wm_instance,
-		   list->main_window_desc->wm_instance) == 0
-	    &&
-	    strcmp(wwin->wm_class,
-		   list->main_window_desc->wm_class) == 0)
-	    index++;
-
-	list = list->next;
-    }
-    
-    puts("OH SHIT!?!?!? HOW THE FUCK DID WE GET HERE!?!?!?!?!");
-    
-    return 0;
+    return app->index;
 }
 
