@@ -225,14 +225,13 @@ static int setCursor();
 
 static WOptionEnumeration seFocusModes[] = {
     {"Manual", WKF_CLICK, 0}, {"ClickToFocus", WKF_CLICK, 1},
-    {"Auto", WKF_POINTER, 0}, {"FocusFollowMouse", WKF_POINTER, 1},
-    {"Sloppy", WKF_SLOPPY, 0}, {"SemiAuto", WKF_SLOPPY, 1},
+    {"Sloppy", WKF_SLOPPY, 0}, {"SemiAuto", WKF_SLOPPY, 1}, {"Auto", WKF_SLOPPY, 1},
     {NULL, 0, 0}
 };
 
 static WOptionEnumeration seColormapModes[] = {
-    {"Manual", WKF_CLICK, 0}, {"ClickToFocus", WKF_CLICK, 1},
-    {"Auto", WKF_POINTER, 0}, {"FocusFollowMouse", WKF_POINTER, 1},
+    {"Manual", WCM_CLICK, 0}, {"ClickToFocus", WCM_CLICK, 1},
+    {"Auto", WCM_POINTER, 0}, {"FocusFollowMouse", WCM_POINTER, 1},
     {NULL, 0, 0}
 };
 
@@ -246,6 +245,7 @@ static WOptionEnumeration sePlacements[] = {
 };
 
 static WOptionEnumeration seGeomDisplays[] = {
+    {"None", WDIS_NONE, 0},
     {"Center", WDIS_CENTER, 0},
     {"Corner", WDIS_TOPLEFT, 0},
     {"Floating", WDIS_FRAME_CENTER, 0},
@@ -420,7 +420,7 @@ WDefaultEntry optionList[] = {
     {"RaiseDelay",	"0",			NULL,
 	  &wPreferences.raise_delay,	getInt,		NULL
     },
-    {"WindozeCycling",  "YES",			NULL,
+    {"WindozeCycling",  "NO",			NULL,
 	  &wPreferences.windows_cycling,getBool,	NULL
     },
     {"CirculateRaise",	"NO",			NULL,
@@ -702,6 +702,9 @@ WDefaultEntry optionList[] = {
     {"VMaximizeKey", "None",			(void*)WKBD_VMAXIMIZE,
 	  NULL,				getKeybind,	setKeyGrab
     },
+    {"HMaximizeKey", "None",			(void*)WKBD_HMAXIMIZE,
+	  NULL,				getKeybind,	setKeyGrab
+    },
     {"RaiseKey", "\"Meta+Up\"",			(void*)WKBD_RAISE,
 	  NULL,				getKeybind,	setKeyGrab
     },
@@ -968,7 +971,7 @@ wDefaultsInitDomain(char *domain, Bool requireDictionary)
     }
 
     /* global system dictionary */
-    sprintf(path, "%s/WindowMaker/%s", SYSCONFDIR, domain);
+    snprintf(path, sizeof(path), "%s/WindowMaker/%s", SYSCONFDIR, domain);
     if (stat(path, &stbuf)>=0) {
         shared_dict = ReadProplistFromFile(path);
         if (shared_dict) {
@@ -1063,7 +1066,7 @@ wDefaultsCheckDomains(void *foo)
 	WDWindowMaker->timestamp = stbuf.st_mtime;	
 
 	/* global dictionary */
-	sprintf(path, "%s/WindowMaker/WindowMaker", SYSCONFDIR);
+	snprintf(path, sizeof(path), "%s/WindowMaker/WindowMaker", SYSCONFDIR);
 	if (stat(path, &stbuf)>=0) {
 	    shared_dict = ReadProplistFromFile(path);
 	    if (shared_dict && !PLIsDictionary(shared_dict)) {
@@ -3240,15 +3243,17 @@ setWorkspaceBack(WScreen *scr, WDefaultEntry *entry, proplist_t value,
 	char *command;
         char *text;
         char *dither;
+	int len;
 
 	SetupEnvironment(scr);
 	text = PLGetDescription(value);
-        command = wmalloc(strlen(text)+40);
+	len = strlen(text)+40;
+        command = wmalloc(len);
         dither = wPreferences.no_dithering ? "-m" : "-d";
 	if (wPreferences.smooth_workspace_back)
-	    sprintf(command, "wmsetbg %s -S -p '%s' &", dither, text);
+	    snprintf(command, len, "wmsetbg %s -S -p '%s' &", dither, text);
 	else
-	    sprintf(command, "wmsetbg %s -p '%s' &", dither, text);
+	    snprintf(command, len, "wmsetbg %s -p '%s' &", dither, text);
 	wfree(text);
 	system(command);
 	wfree(command);
