@@ -94,6 +94,9 @@ void PlaceIcon(WScreen *scr, int *x_ret, int *y_ret);
 void PlaceWindow(WWindow *wwin, int *x_ret, int *y_ret,
                  unsigned int width, unsigned int height);
 
+
+void StartWindozeCycle(WWindow *wwin, XEvent *event, Bool next);
+
 #ifdef USECPP
 char *MakeCPPArgs(char *path);
 #endif
@@ -121,8 +124,6 @@ BOOL StringCompareHook(proplist_t pl1, proplist_t pl2);
 
 int IsEof(FILE * stream);	/* feof that stats pipes */
 
-char *FlattenStringList(char **list, int count);
-
 void ParseWindowName(proplist_t value, char **winstance, char **wclass,
                      char *where);
 
@@ -146,9 +147,6 @@ void wHackedGrabButton(unsigned int button, unsigned int modifiers,
 		       int keyboard_mode, Window confine_to, Cursor cursor);
 
 
-/* this function is in dock.c */
-void ParseCommand(char *command, char ***argv, int *argc);
-
 void ExecExitScript();
 
 /****** I18N Wrapper for XFetchName,XGetIconName ******/
