@@ -1587,8 +1587,7 @@ wUnmanageWindow(WWindow *wwin, Bool restore, Bool destroyed)
 
 	   newFocusedWindow = tmp;
 
-	} else if (wPreferences.focus_mode==WKF_SLOPPY
-		   || wPreferences.focus_mode==WKF_POINTER) {
+	} else if (wPreferences.focus_mode==WKF_SLOPPY) {
             unsigned int mask;
             int foo;
             Window bar, win;
@@ -1791,11 +1790,13 @@ wWindowUpdateName(WWindow *wwin, char *newTitle)
 	title = newTitle;
     }
     
+#ifndef NO_WINDOW_ENUMERATOR
     if (instIndex > 0) {
-	sprintf(prefix, "  [%i]", instIndex);
+	snprintf(prefix, sizeof(prefix), "  [%i]", instIndex);
 	
 	title = wstrconcat(title, prefix);
     }
+#endif
     
     if (wFrameWindowChangeTitle(wwin->frame, title)) {
 	/* only update the menu if the title has actually changed */
@@ -1804,8 +1805,12 @@ wWindowUpdateName(WWindow *wwin, char *newTitle)
 	wKWMSendEventMessage(wwin, WKWMChangedClient);
 #endif
     }
+
+#ifndef NO_WINDOW_ENUMERATOR
     if (instIndex > 0)
 	wfree(title);
+#endif
+
 }
 
 
@@ -1851,6 +1856,9 @@ wWindowConstrainSize(WWindow *wwin, int *nwidth, int *nheight)
 	    maxAX = wwin->normal_hints->max_aspect.x;
 	    maxAY = wwin->normal_hints->max_aspect.y;
 	}
+	
+	baseW = wwin->normal_hints->base_width;
+	baseH = wwin->normal_hints->base_height;
     }
 
     if (width < minW)
@@ -1906,7 +1914,7 @@ wWindowConstrainSize(WWindow *wwin, int *nwidth, int *nheight)
 	width = (((width - minW) / winc) * winc) + minW;
     }
 
-    if (baseW != 0) {
+    if (baseH != 0) {
 	height = (((height - baseH) / hinc) * hinc) + baseH;
     } else {
 	height = (((height - minH) / hinc) * hinc) + minH;
@@ -1920,6 +1928,29 @@ wWindowConstrainSize(WWindow *wwin, int *nwidth, int *nheight)
 }
 
 
+void
+wWindowCropSize(WWindow *wwin, int maxW, int maxH, 
+		int *width, int *height)
+{
+    int baseW = 0, baseH = 0;
+    int winc = 1, hinc = 1;
+
+    if (wwin->normal_hints) {
+	baseW = wwin->normal_hints->base_width;
+	baseH = wwin->normal_hints->base_height;
+	
+	winc = wwin->normal_hints->width_inc;
+	hinc = wwin->normal_hints->height_inc;	
+    }
+
+    if (*width > maxW)
+	*width = maxW - (maxW - baseW) % winc;
+
+    if (*height > maxH)
+	*height = maxH - (maxH - baseH) % hinc;    
+}
+
+
 void
 wWindowChangeWorkspace(WWindow *wwin, int workspace)
 {
